diff mbox series

[ovs-dev,v2,3/5] netdev-linux: Rename sturct nedev_linux field as is_lag_primary

Message ID 20240301-dei-t1-v2-3-10ee89c17b89@ovn.org
State Accepted
Delegated to: Simon Horman
Headers show
Series DEI: Address some instances of master and slave | expand

Checks

Context Check Description
ovsrobot/apply-robot warning apply and check: warning
ovsrobot/github-robot-_Build_and_Test fail github build: failed
ovsrobot/intel-ovs-compilation success test: success

Commit Message

Simon Horman March 1, 2024, 2:50 p.m. UTC
Recently OVS adopted a policy of using the inclusive naming word list v1
[1, 2].

This patch partially addresses the use of the term master in the
context of LAG devices by using the term primary instead: the
is_lag_master field of struct netdev_linux is renamed is_lag_primary.

A related comment is also updated.

No functional change intended.

[1] df5e5cf ("Documentation: Add section on inclusive language.")
[2] https://inclusivenaming.org/word-lists/

Signed-off-by: Simon Horman <horms@ovn.org>
---
 lib/netdev-linux-private.h | 2 +-
 lib/netdev-linux.c         | 9 +++++----
 2 files changed, 6 insertions(+), 5 deletions(-)

Comments

0-day Robot March 1, 2024, 3:03 p.m. UTC | #1
Bleep bloop.  Greetings Simon Horman, I am a robot and I have tried out your patch.
Thanks for your contribution.

I encountered some error that I wasn't expecting.  See the details below.


checkpatch:
WARNING: The subject summary should end with a dot.
Subject: netdev-linux: Rename sturct nedev_linux field as is_lag_primary
Lines checked: 76, Warnings: 1, Errors: 0


Please check this out.  If you feel there has been an error, please email aconole@redhat.com

Thanks,
0-day Robot
Eelco Chaudron March 1, 2024, 4:41 p.m. UTC | #2
On 1 Mar 2024, at 15:50, Simon Horman wrote:

> Recently OVS adopted a policy of using the inclusive naming word list v1
> [1, 2].
>
> This patch partially addresses the use of the term master in the
> context of LAG devices by using the term primary instead: the
> is_lag_master field of struct netdev_linux is renamed is_lag_primary.
>
> A related comment is also updated.
>
> No functional change intended.
>
> [1] df5e5cf ("Documentation: Add section on inclusive language.")
> [2] https://inclusivenaming.org/word-lists/
>
> Signed-off-by: Simon Horman <horms@ovn.org>

Thanks for fixing these. Except for the missing dot in the subject, the changes look good to me. Assuming you will fix this when applying;

Acked-by: Eelco Chaudron <echaudro@redhat.com>

//Eelco
Simon Horman March 6, 2024, 10:11 a.m. UTC | #3
On Fri, Mar 01, 2024 at 05:41:44PM +0100, Eelco Chaudron wrote:
> 
> 
> On 1 Mar 2024, at 15:50, Simon Horman wrote:
> 
> > Recently OVS adopted a policy of using the inclusive naming word list v1
> > [1, 2].
> >
> > This patch partially addresses the use of the term master in the
> > context of LAG devices by using the term primary instead: the
> > is_lag_master field of struct netdev_linux is renamed is_lag_primary.
> >
> > A related comment is also updated.
> >
> > No functional change intended.
> >
> > [1] df5e5cf ("Documentation: Add section on inclusive language.")
> > [2] https://inclusivenaming.org/word-lists/
> >
> > Signed-off-by: Simon Horman <horms@ovn.org>
> 
> Thanks for fixing these. Except for the missing dot in the subject, the changes look good to me. Assuming you will fix this when applying;

Thanks Eelco, will do.

> Acked-by: Eelco Chaudron <echaudro@redhat.com>
> 
> //Eelco
>
diff mbox series

Patch

diff --git a/lib/netdev-linux-private.h b/lib/netdev-linux-private.h
index 188e8438a320..8e572e3b3b14 100644
--- a/lib/netdev-linux-private.h
+++ b/lib/netdev-linux-private.h
@@ -105,7 +105,7 @@  struct netdev_linux {
     uint64_t rx_dropped;        /* Packets dropped while recv from kernel. */
 
     /* LAG information. */
-    bool is_lag_master;         /* True if the netdev is a LAG master. */
+    bool is_lag_primary;        /* True if the netdev is a LAG primary. */
 
     int numa_id;                /* NUMA node id. */
 
diff --git a/lib/netdev-linux.c b/lib/netdev-linux.c
index bf91ef462efb..1f996454d8f6 100644
--- a/lib/netdev-linux.c
+++ b/lib/netdev-linux.c
@@ -885,7 +885,7 @@  netdev_linux_update__(struct netdev_linux *dev,
             }
 
             if (change->primary && netdev_linux_kind_is_lag(change->primary)) {
-                dev->is_lag_master = true;
+                dev->is_lag_primary = true;
             }
 
             dev->ifindex = change->if_index;
@@ -3703,8 +3703,9 @@  netdev_linux_get_block_id(struct netdev *netdev_)
         netdev_linux_update_via_netlink(netdev);
     }
 
-    /* Only assigning block ids to linux netdevs that are LAG masters. */
-    if (netdev->is_lag_master) {
+    /* Only assigning block ids to linux netdevs that are
+     * LAG primary members. */
+    if (netdev->is_lag_primary) {
         block_id = netdev->ifindex;
     }
     ovs_mutex_unlock(&netdev->mutex);
@@ -6903,7 +6904,7 @@  netdev_linux_update_via_netlink(struct netdev_linux *netdev)
             changed = true;
         }
         if (change->primary && netdev_linux_kind_is_lag(change->primary)) {
-            netdev->is_lag_master = true;
+            netdev->is_lag_primary = true;
         }
         if (changed) {
             netdev_change_seq_changed(&netdev->up);